==> haskell-easy-file-0.2.5-39-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-Azw6RnuDQzR6ZoiNvPUE9O
key:                  easy-file-0.2.5-Azw6RnuDQzR6ZoiNvPUE9O
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  9cbe6c1f7daa1eb5159329a5b37686a5
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-Azw6RnuDQzR6ZoiNvPUE9O
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 time-1.12.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-easy-file-0.2.5-42-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-easy-file.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 easy-file
version:              0.2.5
visibility:           public
id:                   easy-file-0.2.5-Hff8cTfThu76DCrSHZtn6i
key:                  easy-file-0.2.5-Hff8cTfThu76DCrSHZtn6i
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             http://github.com/kazu-yamamoto/easy-file
synopsis:             Cross-platform File handling
description:          Cross-platform File handling for Unix\/Mac\/Windows
category:             System
abi:                  af687e632b00a1020bae0aa63257bbbd
exposed:              True
exposed-modules:      System.EasyFile
hidden-modules:
    System.EasyFile.FilePath System.EasyFile.Directory
    System.EasyFile.Missing

import-dirs:          /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
library-dirs:         /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/easy-file-0.2.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-easy-file
hs-libraries:         HSeasy-file-0.2.5-Hff8cTfThu76DCrSHZtn6i
depends:
    base-4.17.2.1 directory-1.3.7.1 filepath-1.4.2.2 time-1.12.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-easy-file/html/easy-file.haddock
haddock-html:         /usr/share/doc/haskell-easy-file/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
